@@ -1,5 +1,5 @@
 ;;; cheat-font-lock.el --- modify font-lock-keywords
-;;; Copyright (C) 2002, 2003, 2004, 2005-2019
+;;; Copyright (C) 2002, 2003, 2004, 2005-2020
 ;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -105,7 +105,10 @@
   (font-lock-set-defaults))
 
 (defun cheat-font-lock-fontify (&optional dummy)
-  (font-lock-fontify-buffer))
+  (if (fboundp 'font-lock-ensure)
+      (font-lock-ensure)
+    (with-no-warnings
+      (font-lock-fontify-buffer))))
 
 (provide 'cheat-font-lock)
 
