@@ -1,5 +1,5 @@
 ;;; howm-common.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2002, 2003, 2004, 2005-2019
+;;; Copyright (C) 2002, 2003, 2004, 2005-2020
 ;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -436,7 +436,7 @@ Use `howm-view-in-background' and `howm-view-in-background-p' instead.")
   "List of arguments for last `howm-call-process'.
 This variable exists only for debug. You can reproduce the last call
 with the below code.
- (apply #'howm-call-process howm-call-process-last-command)")
+ (apply (function howm-call-process) howm-call-process-last-command)")
 
 (defmacro howm-with-coding-system (coding-system &rest body)
   "With CODING-SYSTEM, execute BODY.
